************
Installation
************


Installing |gaussdecomp|
========================

The easiest way to install |gaussdecomp| is with PyPi.

.. code-block:: bash

    pip install gaussdecomp

To get the very latest version of the software, install it directly from GitHub.
    
.. code-block:: bash

    pip install git+https://github.com/dnidever/gaussdecomp


If you are using the IDL code, you will also need to download the IDL Astronomer User's Library (if you haven't already).  You can use the `website <http://idlastro.gsfc.nasa.gov/ftp/>`_ or the `GitHub repository <https://github.com/wlandsman/IDLAstro>`_.

Make sure to update your `IDL_PATH` environmental variable to include the paths to these two packages.

    

Dependencies
============

- numpy
- scipy
- astropy
- matplotlib
- dlnpyutils
